@@ -99,7 +99,7 @@ class BaseModelEvaluatorBuilder(JavaObject):
 		self.javaModelEvaluatorBuilder = javaModelEvaluatorBuilder
 
 	def setReportingValueFactoryFactory(self):
-		javaValueFactoryFactory = self.backend.staticInvoke("org.jpmml.evaluator.ReportingValueFactoryFactory", "newInstance")
+		javaValueFactoryFactory = self.backend.staticInvoke("org.jpmml.evaluator.reporting.ReportingValueFactoryFactory", "newInstance")
 		self.javaModelEvaluatorBuilder.setValueFactoryFactory(javaValueFactoryFactory)
 		return self
 
@@ -123,11 +123,6 @@ class LoadingModelEvaluatorBuilder(BaseModelEvaluatorBuilder):
 		self.javaModelEvaluatorBuilder.setLocatable(locatable)
 		return self
 
-	def setDefaultVisitorBattery(self):
-		visitors = self.backend.newObject("org.jpmml.evaluator.DefaultVisitorBattery")
-		self.javaModelEvaluatorBuilder.setVisitors(visitors)
-		return self
-
 	def loadFile(self, path):
 		file = self.backend.newObject("java.io.File", path)
 		self.javaModelEvaluatorBuilder.load(file)
