@@ -1,6 +1,7 @@
 from jpmml_evaluator import _classpath, JavaBackend
 
 import jnius_config
+import numpy
 
 def jnius_configure_classpath(user_classpath = []):
 	jnius_config.set_classpath(*_classpath(user_classpath))
@@ -23,12 +24,18 @@ class PyJNIusBackend(JavaBackend):
 				javaValue = self.newObject("java.lang.String", v)
 			elif isinstance(v, int):
 				javaValue = self.newObject("java.lang.Integer", v)
+			elif isinstance(v, numpy.int8) or isinstance(v, numpy.int16) or isinstance(v, numpy.int32):
+				javaValue = self.newObject("java.lang.Integer", int(v))
+			elif isinstance(v, numpy.float32):
+				javaValue = self.newObject("java.lang.Float", float(v))
 			elif isinstance(v, float):
 				javaValue = self.newObject("java.lang.Double", v)
+			elif isinstance(v, numpy.float64):
+				javaValue = self.newObject("java.lang.Double", float(v))
 			elif isinstance(v, bool):
 				javaValue = self.newObject("java.lang.Boolean", v)
 			else:
-				raise ValueError()
+				raise ValueError("Python data type {0} is not supported".format(type(v)))
 			javaMap.put(javaKey, javaValue)
 		return javaMap
 
